SystemOrganization addCategory: #GODCallTests!

TestCase subclass: #GCConfSearchCrawlerTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODCallTests'!

!GCConfSearchCrawlerTest methodsFor: 'testing' stamp: 'pfsm 10/18/2014 19:47'!
testParse
	|fileData mockPath conferences crawler conference1 conference2 keywords|
	
	mockPath := '/home/camila/Dropbox/POO 2014/confsearchpage.html'.	
     fileData := (StandardFileStream fileNamed: mockPath ) contentsOfEntireFile.
	crawler := GCConfSearchCrawler new.
	conferences :=  crawler parse: fileData.
	self assert: (conferences size)  = 32.
	
	conference1 := conferences at: 2.
	conference2 := conferences at: 3.

	self assert: conference1 acronym = 'flairs'.
	self assert: conference1 name = 'The Florida AI Research Society (FLAIRS)'.
	self assert: conference1 url = 'http://www.flairs-28.info/'.
	self assert: (conference1 importantDates) deadlineDate = '17 Nov 14'.
	self assert: (conference1 importantDates) startDate = '18 May 15'.
	self assert: (conference1 importantDates) endDate = '20 May 15'.
	self assert: (conference1 venue) city = 'Hollywood'.
	self assert: (conference1 venue) country = 'USA'. 
	keywords := conference1 keywords.
	self assert: keywords size = 7.
	self assert: (keywords includes: 'knowledge').
	self assert: (keywords includes: 'learning').
	self assert: (keywords includes: 'reasoning').
	self assert: (keywords includes: 'based').
	self assert: (keywords includes: 'using').
	self assert: (keywords includes: 'tutoring').
	self assert: (keywords includes: 'neural').
		

	self assert: conference2 acronym = 'aia'.
	self assert: conference2 name = 'Artificial Intelligence and Applications'.
	self assert: conference2 url = 'http://www.iasted.org/conferences/home-793.html'.
	self assert: (conference2 importantDates) deadlineDate = '03 Dec 12'.
	self assert: (conference2 importantDates) startDate = '11 Feb 13'.
	self assert: (conference2 importantDates) endDate = '13 Feb 13'.
	self assert: (conference2 venue) city = 'Innsbruck'.
	self assert: (conference2 venue) country = 'Austria'. 
	keywords := conference2 keywords.
	self assert: keywords size = 8.
	self assert: (keywords includes: 'neural').
	self assert: (keywords includes: 'genetic').
	self assert: (keywords includes: 'using').
	self assert: (keywords includes: 'artificial').
	self assert: (keywords includes: 'fuzzy').
	self assert: (keywords includes: 'algorithm').	
	self assert: (keywords includes: 'network').
	self assert: (keywords includes: 'networks').
	! !

!GCConfSearchCrawlerTest methodsFor: 'testing' stamp: 'cms 10/18/2014 01:17'!
testParseVenue
	|locationString venue crawler|
	crawler := GCConfSearchCrawler new.
	locationString := 'Spain, Tenerife'.
	venue := crawler parseVenue: locationString.
	self assert: venue city = 'Tenerife'.
	self assert: venue country = 'Spain'.

	locationString := 'Spain,'.
	venue := crawler parseVenue: locationString.
	self assert: venue city = nil.
	self assert: venue country = 'Spain'.

	locationString := 'USA, Hollywood, Florida, USA'.
	venue := crawler parseVenue: locationString.
	self assert: venue city = 'Hollywood'.
	self assert: venue country = 'USA'.! !

TestCase subclass: #GCConferenceTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODCallTests'!

!GCConferenceTest methodsFor: 'testing' stamp: 'cms 10/18/2014 17:02'!
testFromSpreadhsheet
	"test if given a spreadsheet with conference data it is converted to GODConferences correctly"
	 |spreadsheet godConferencesCollection|
	"when tested, we didnt get a valid spreadsheet"
	spreadsheet := GCConference from: (SSSpreadsheetData fromCSV: '/home/camila/Dropbox/POO 2014/conferencesMock.csv').
	godConferencesCollection := GCConference from: spreadsheet.
	
	godConferencesCollection do: [ :godConference | 
		self assert: godConference getName = 'Artificial Intelligence and Applications'
	]! !

!GCConferenceTest methodsFor: 'testing' stamp: 'cms 10/18/2014 15:20'!
testGenerateGODConferencesFromSpreadsheet
	"cant remove it..."! !

!GCConferenceTest methodsFor: 'testing' stamp: 'cms 10/18/2014 16:41'!
testToSpreedsheet
	|collection conference spreadsheet
	sheet rows
	conferenceName conferenceAcronym conferenceUrl
	conferenceKeywords conferenceStartDate conferenceEndDate conferenceDeadlineDate 
	conferenceCity conferenceCountry|


	conference := GCConference new.
	conferenceAcronym := 'aia'.
	conferenceName := 'Artificial Intelligence and Applications'.
	conferenceKeywords := Set new.
	conferenceKeywords add: 'neural'; add: 'genetic'.
	conferenceUrl:= 'http://conferences'.
	conferenceDeadlineDate := '24 mar 14'.
	conferenceStartDate := '20 abr 14'.
	conferenceEndDate := '25 abr 14'.
	conferenceCity := 'Holywood'.
	conferenceCountry := 'USA'.

	conference acronym: conferenceAcronym.	
	conference name: conferenceName.
	conference url: conferenceUrl.
	conference keywords: conferenceKeywords.
	conference importantDates: GCImportantDates new.
	conference importantDates deadlineDate: conferenceDeadlineDate.	
	conference importantDates startDate: conferenceStartDate.	
	conference importantDates endDate: conferenceEndDate.	
	conference venue: GCVenue new.
	conference venue city: conferenceCity.
	conference venue country: conferenceCountry.
	collection := OrderedCollection new.
	collection add: conference.
	spreadsheet  := GCConference asSpreadsheet: collection.
	sheet := spreadsheet getSheet: 1.
	rows := sheet rows.
	rows do: [:row |
		self assert: (row getCell: 'acronym') = conferenceAcronym.
		self assert: (row getCell: 'name') = conferenceName.
		self assert: (row getCell: 'keywords') = conferenceKeywords.
		self assert: (row getCell: 'url') = conferenceUrl.
		self assert: (row getCell: 'city') = conferenceCity.
		self assert: (row getCell: 'country') = conferenceCountry.
		self assert: (row getCell: 'deadlineDate') = conferenceDeadlineDate.
		self assert: (row getCell: 'startDate') = conferenceStartDate.
		self assert: (row getCell: 'endDate') = conferenceEndDate.
	].
	
	
	! !

TestCase subclass: #GCWikiCfpCrawlerTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODCallTests'!

!GCWikiCfpCrawlerTest class methodsFor: 'filtering' stamp: 'pfsm 10/16/2014 17:26'!
filter: aText startMark: startMark endMark: endMark
	"comment stating purpose of message"

	| regex prefix suffix matches|

	prefix:= startMark copyReplaceAll: ':' with: '\:'.
	prefix := prefix copyReplaceAll: '?' with: '\?'.
	suffix:= endMark copyReplaceAll: ':' with: '\:'.
	suffix := suffix copyReplaceAll: '?' with: '\?'.

	regex:= (prefix,'(\w|\s|[-]|[.]|[:]|[/]|[,]|[?])*',suffix) asRegexIgnoringCase.

	matches := regex matchesIn: aText collect: [:match | 	match:= match copyReplaceAll: startMark with: String empty.
																					match copyReplaceAll: endMark with: String empty.
																	].

	^matches.! !

!GCWikiCfpCrawlerTest methodsFor: 'testing' stamp: 'pfsm 10/18/2014 21:39'!
testParse	
	"method for testing GCWikiCfpCrawler>>parse"

	| conference1 conference2  mockPath fileData crawler|
	
	mockPath := 'wikicfppage_conference1.html'.	
     fileData := (StandardFileStream fileNamed: mockPath ) contentsOfEntireFile.
	crawler := GCWikiCfpCrawler new.
	conference1 := crawler parse: fileData.

	self assert: conference1 acronym = 'LATA'.
	self assert: conference1 name = '9th INTERNATIONAL CONFERENCE ON LANGUAGE AND AUTOMATA THEORY AND APPLICATIONS'.
	self assert: conference1 edition = '2015'.
	self assert: (conference1 url) asString = 'http://grammars.grlmc.com/lata2015/'.
	self assert: (conference1 importantDates) deadlineDate = ('10 October 2014' asDate).
	self assert: (conference1 importantDates) startDate = ('2 Mar 2015' asDate).
	self assert: (conference1 importantDates) endDate = ('6 Mar 2015' asDate).
	self assert: (conference1 venue) city = 'Nice'.
	self assert: (conference1 venue) country = 'France'. 	
	self assert: (conference1 categories)  =  (Set with:  'theoretical computer science' with: 'nlp'). 	



	mockPath := 'wikicfppage_conference2.html'.	
     fileData := (StandardFileStream fileNamed: mockPath ) contentsOfEntireFile.
	crawler := GCWikiCfpCrawler new.
	conference2 := crawler parse: fileData.

	self assert: conference2 acronym = 'LICS'.
	self assert: conference2 name = '28th Annual ACM/IEEE Symposium on Logic In Computer Science'.
	self assert: conference2 edition = '2013'.
	self assert: (conference2 url) asString = 'http://www2.informatik.hu-berlin.de/lics/lics13/'.
	self assert: (conference2 importantDates) deadlineDate = ('2013-01-07' asDate).
	self assert: (conference2 importantDates) startDate = ('2013-06-25' asDate).
	self assert: (conference2 importantDates) endDate = ('2013-06-28' asDate).
	self assert: (conference2 venue) city = 'New Orleans'.
	self assert: (conference2 venue) country = 'USA'. 	
	self assert: (conference2 categories)  =  (Set with:  'theoretical computer science' with: 'logic'). 	
! !

TestCase subclass: #GODCallTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODCallTests'!

!GODCallTest methodsFor: 'generating' stamp: 'pfsm 10/18/2014 21:47'!
generateConferences
	"generate a list of conferences from html files"
	|mockPath fileData crawler conferences|

	crawler := GCWikiCfpCrawler new.

	mockPath := 'wikicfppage_conference1.html'.	
     fileData := (StandardFileStream fileNamed: mockPath ) contentsOfEntireFile.

	conferences := OrderedCollection new.	
	
	conferences add: (crawler parse: fileData).

	mockPath := 'wikicfppage_conference2.html'.	
     fileData := (StandardFileStream fileNamed: mockPath ) contentsOfEntireFile.

	conferences add: (crawler parse: fileData).

^ conferences.! !

!GODCallTest methodsFor: 'testing' stamp: 'pfsm 10/18/2014 22:11'!
testConferencesFilter
	"emulate a user's search"

	|filteredConferences  searchFilter  conferences filter|

	searchFilter := GCSearchFilter new.
	searchFilter searchKey: '9th INTERNATIONAL CONFERENCE ON LANGUAGE AND AUTOMATA THEORY AND APPLICATIONS'.
	searchFilter category: (Set with:  'theoretical computer science' with: 'nlp').
	searchFilter startDate: (Date year:2010 month: 1 day: 1).
	searchFilter endDate: (Date year:2015 month: #December  day: 1).
	searchFilter deadlineDate: (Date year:2015 month: #December  day: 1).

	conferences := self generateConferences.

	filter:= FILTConferenceFilter new.
	
	filteredConferences := filter filter: conferences byGCSearchFilter: searchFilter.	
	
	self assert: filteredConferences size = 1.
	self assert: (filteredConferences at: 1) acronym = 'LATA'.
	self assert: (filteredConferences at: 1) name = '9th INTERNATIONAL CONFERENCE ON LANGUAGE AND AUTOMATA THEORY AND APPLICATIONS'.
	self assert: (filteredConferences at: 1) edition = '2015'.
	self assert: ((filteredConferences at: 1) url) asString = 'http://grammars.grlmc.com/lata2015/'.
	self assert: ((filteredConferences at: 1) importantDates) deadlineDate = ('10 October 2014' asDate).
	self assert: ((filteredConferences at: 1) importantDates) startDate = ('2 Mar 2015' asDate).
	self assert: ((filteredConferences at: 1) importantDates) endDate = ('6 Mar 2015' asDate).
	self assert: ((filteredConferences at: 1) venue) city = 'Nice'.
	self assert: ((filteredConferences at: 1) venue) country = 'France'. 	
	self assert: ((filteredConferences at: 1) categories)  =  (Set with:  'theoretical computer science' with: 'nlp'). 	

	
! !
